Functions specific to the CircleCI server.
Functions specific to the CircleCI server.
(split-name {:keys [name]})CircleCI combines the owner and project name into the cctray xml name attribute.
This function splits the name into individual entries in the project map.
So instead of:
{:name "Owner/Project Name"}
You end up with:
{:name "Project Name"
:owner "Owner"}
CircleCI combines the owner and project name into the cctray xml name attribute.
This function splits the name into individual entries in the project map.
So instead of:
{:name "Owner/Project Name"}
You end up with:
{:name "Project Name"
:owner "Owner"}cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |