Functions specific to the Go CI server.
Functions specific to the Go CI server.
(normalise-job project)Normalises the job name in the given project map.
Normalises the job name in the given project map.
(normalise-stage project)Normalises the stage name in the given project map.
Normalises the stage name in the given project map.
(split-name {:keys [name]})Go combines the project name, stage and job into the cctray xml name attribute, using :: as a delimter.
This function splits the name into individual entries in the project map.
So instead of:
{:name "Project Name :: Stage Name :: Job Name"}
You end up with:
{:name "Project Name"
:stage "Stage Name"
:job "Job Name"}
Go combines the project name, stage and job into the cctray xml name attribute, using :: as a delimter.
This function splits the name into individual entries in the project map.
So instead of:
{:name "Project Name :: Stage Name :: Job Name"}
You end up with:
{:name "Project Name"
:stage "Stage Name"
:job "Job Name"}cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |