Contains the core public function to get parsed projects.
Contains the core public function to get parsed projects.
(get-projects source)(get-projects source user-supplied-options)Gets and parses the cctray xml file at the given source and returns a list of project maps.
An optional map of options can be given to modify how the file is parsed.
See the project README at https://github.com/build-canaries/clj-cctray/blob/master/README.md for more details about available options and the keys in each project map.
Gets and parses the cctray xml file at the given source and returns a list of project maps. An optional map of options can be given to modify how the file is parsed. See the project README at https://github.com/build-canaries/clj-cctray/blob/master/README.md for more details about available options and the keys in each project map.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |