Functions for converting dates found in the CCTray XML.
Functions for converting dates found in the CCTray XML.
(extract-dates {:keys [last-build-time next-build-time]})Extracts the last and next build times from the CCTray XML into real DateTime objects.
Extracts the last and next build times from the CCTray XML into real DateTime objects.
Format string in the ISO 8601 format, yyyy-MM-dd'T'HH:mm:ss.SSSVV
Format string in the ISO 8601 format, yyyy-MM-dd'T'HH:mm:ss.SSSVV
(print-dates format {:keys [last-build-time next-build-time]})Prints the last and next build times using the given string format. They must be DateTime objects to be printed
correctly using the format string, if any other object is found it will just be converted to a string using str
Prints the last and next build times using the given string format. They must be DateTime objects to be printed correctly using the format string, if any other object is found it will just be converted to a string using `str`
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |