Functions for extracting the health from CCTray XML.
Functions for extracting the health from CCTray XML.
(add-prognosis {:keys [last-build-status activity]})Returns a prognosis which is based on the last build status and activity.
Returns a prognosis which is based on the last build status and activity.
(keyword-activity {:keys [activity]})Converts the activity value into a keyword.
Converts the activity value into a keyword.
(keyword-status {:keys [last-build-status]})Converts the last build status value into a keyword.
Converts the last build status value into a keyword.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |