Clojure only.

clj-cctray.messages


extract-messagesclj

(extract-messages {:keys [content]})

Extracts any messages attached to the project as a seq of strings.

Extracts any messages attached to the project as a seq of strings.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries