Clojure only.

clj-cctray.name

Functions for normalising and converting names.

Functions for normalising and converting names.
raw docstring

normalise-nameclj

(normalise-name project)

Normalise the project name in the given project map.

Normalise the project name in the given project map.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries