Clojure only.

clj-cctray.owner

Functions for normalising and converting owners.

Functions for normalising and converting owners.
raw docstring

normalise-ownerclj

(normalise-owner project)

Normalises the owner name in the given project map.

Normalises the owner name in the given project map.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries