Clojure only.

clj-cctray.parser

Main functions for parsing the CCTray XML.

Main functions for parsing the CCTray XML.
raw docstring

get-projectsclj

(get-projects source)
(get-projects source modifiers)

Gets a list of projects from the given source converted into a nice clojure map. The source may be a File, InputStream or String naming a URI

Gets a list of projects from the given source converted into a nice clojure map. The source may be a File,
InputStream or String naming a URI
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries