Functions for normalising and converting names.
Functions for normalising and converting names.
(normalise-name project)Normalise the project name in the given project map.
Normalise the project name in the given project map.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |