Functions for normalising and converting owners.
Functions for normalising and converting owners.
(normalise-owner project)Normalises the owner name in the given project map.
Normalises the owner name in the given project map.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |