Main functions for parsing the CCTray XML.
Main functions for parsing the CCTray XML.
(get-projects source)(get-projects source modifiers)Gets a list of projects from the given source converted into a nice clojure map. The source may be a File, InputStream or String naming a URI
Gets a list of projects from the given source converted into a nice clojure map. The source may be a File, InputStream or String naming a URI
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |